==> camel-k-model-v1-6.1.0-sources.jar: io/fabric8/camelk/v1/RuntimeSpecFluent.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface RuntimeSpecFluent<A extends RuntimeSpecFluent<A>> extends Fluent<A>{
  public String getApplicationClass();
  public A withApplicationClass(String applicationClass);
  public Boolean hasApplicationClass();
  public A addToCapabilities(String key,Capability value);
  public A addToCapabilities(Map<String,Capability> map);
  public A removeFromCapabilities(String key);
  public A removeFromCapabilities(Map<String,Capability> map);
  public Map<String,Capability> getCapabilities();
  public <K,V>A withCapabilities(Map<String,Capability> capabilities);
  public Boolean hasCapabilities();
  public A addToDependencies(Integer index,MavenArtifact item);
  public A setToDependencies(Integer index,MavenArtifact item);
  public A addToDependencies(io.fabric8.camelk.v1.MavenArtifact... items);
  public A addAllToDependencies(Collection<MavenArtifact> items);
  public A removeFromDependencies(io.fabric8.camelk.v1.MavenArtifact... items);
  public A removeAllFromDependencies(Collection<MavenArtifact> items);
  public A removeMatchingFromDependencies(Predicate<MavenArtifactBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildDependencies instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<MavenArtifact> getDependencies();
  public List<MavenArtifact> buildDependencies();
  public MavenArtifact buildDependency(Integer index);
  public MavenArtifact buildFirstDependency();
  public MavenArtifact buildLastDependency();
  public MavenArtifact buildMatchingDependency(Predicate<MavenArtifactBuilder> predicate);
  public Boolean hasMatchingDependency(Predicate<MavenArtifactBuilder> predicate);
  public A withDependencies(List<MavenArtifact> dependencies);
  public A withDependencies(io.fabric8.camelk.v1.MavenArtifact... dependencies);
  public Boolean hasDependencies();
  public A addNewDependency(String artifactId,String groupId,String version);
  public RuntimeSpecFluent.DependenciesNested<A> addNewDependency();
  public RuntimeSpecFluent.DependenciesNested<A> addNewDependencyLike(MavenArtifact item);
  public RuntimeSpecFluent.DependenciesNested<A> setNewDependencyLike(Integer index,MavenArtifact item);
  public RuntimeSpecFluent.DependenciesNested<A> editDependency(Integer index);
  public RuntimeSpecFluent.DependenciesNested<A> editFirstDependency();
  public RuntimeSpecFluent.DependenciesNested<A> editLastDependency();
  public RuntimeSpecFluent.DependenciesNested<A> editMatchingDependency(Predicate<MavenArtifactBuilder> predicate);
  public A addToMetadata(String key,String value);
  public A addToMetadata(Map<String,String> map);
  public A removeFromMetadata(String key);
  public A removeFromMetadata(Map<String,String> map);
  public Map<String,String> getMetadata();
  public <K,V>A withMetadata(Map<String,String> metadata);
  public Boolean hasMetadata();
  public String getProvider();
  public A withProvider(String provider);
  public Boolean hasProvider();
  public String getVersion();
  public A withVersion(String version);
  public Boolean hasVersion();
  public interface DependenciesNested<N> extends Nested<N>,MavenArtifactFluent<RuntimeSpecFluent.DependenciesNested<N>>{
    public N and();
    public N endDependency();
    
  }
  
}

==> camel-k-model-v1-6.7.2-sources.jar: io/fabric8/camelk/v1/RuntimeSpecFluent.java <==
package io.fabric8.camelk.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface RuntimeSpecFluent<A extends RuntimeSpecFluent<A>> extends Fluent<A>{
  public String getApplicationClass();
  public A withApplicationClass(String applicationClass);
  public Boolean hasApplicationClass();
  public A addToCapabilities(String key,Capability value);
  public A addToCapabilities(Map<String,Capability> map);
  public A removeFromCapabilities(String key);
  public A removeFromCapabilities(Map<String,Capability> map);
  public Map<String,Capability> getCapabilities();
  public <K,V>A withCapabilities(Map<String,Capability> capabilities);
  public Boolean hasCapabilities();
  public A addToDependencies(int index,MavenArtifact item);
  public A setToDependencies(int index,MavenArtifact item);
  public A addToDependencies(io.fabric8.camelk.v1.MavenArtifact... items);
  public A addAllToDependencies(Collection<MavenArtifact> items);
  public A removeFromDependencies(io.fabric8.camelk.v1.MavenArtifact... items);
  public A removeAllFromDependencies(Collection<MavenArtifact> items);
  public A removeMatchingFromDependencies(Predicate<MavenArtifactBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildDependencies instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<MavenArtifact> getDependencies();
  public List<MavenArtifact> buildDependencies();
  public MavenArtifact buildDependency(int index);
  public MavenArtifact buildFirstDependency();
  public MavenArtifact buildLastDependency();
  public MavenArtifact buildMatchingDependency(Predicate<MavenArtifactBuilder> predicate);
  public Boolean hasMatchingDependency(Predicate<MavenArtifactBuilder> predicate);
  public A withDependencies(List<MavenArtifact> dependencies);
  public A withDependencies(io.fabric8.camelk.v1.MavenArtifact... dependencies);
  public Boolean hasDependencies();
  public A addNewDependency(String artifactId,String groupId,String version);
  public RuntimeSpecFluent.DependenciesNested<A> addNewDependency();
  public RuntimeSpecFluent.DependenciesNested<A> addNewDependencyLike(MavenArtifact item);
  public RuntimeSpecFluent.DependenciesNested<A> setNewDependencyLike(int index,MavenArtifact item);
  public RuntimeSpecFluent.DependenciesNested<A> editDependency(int index);
  public RuntimeSpecFluent.DependenciesNested<A> editFirstDependency();
  public RuntimeSpecFluent.DependenciesNested<A> editLastDependency();
  public RuntimeSpecFluent.DependenciesNested<A> editMatchingDependency(Predicate<MavenArtifactBuilder> predicate);
  public A addToMetadata(String key,String value);
  public A addToMetadata(Map<String,String> map);
  public A removeFromMetadata(String key);
  public A removeFromMetadata(Map<String,String> map);
  public Map<String,String> getMetadata();
  public <K,V>A withMetadata(Map<String,String> metadata);
  public Boolean hasMetadata();
  public String getProvider();
  public A withProvider(String provider);
  public Boolean hasProvider();
  public String getVersion();
  public A withVersion(String version);
  public Boolean hasVersion();
  public interface DependenciesNested<N> extends Nested<N>,MavenArtifactFluent<RuntimeSpecFluent.DependenciesNested<N>>{
    public N and();
    public N endDependency();
    
  }
  
}
